<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=lt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Aktyvuoti prašymą',
	'bouton_radio_supprimer_petition' => 'Ištrinti prašymą',

	// F
	'form_pet_adresse_site' => 'Jūsų interneto svetainės adresas', # MODIF
	'form_pet_deja_signe' => 'Jūs jau pasirašėte šį tekstą',
	'form_pet_nom_site2' => 'Jūsų interneto svetainės vardas', # MODIF
	'form_pet_site_deja_enregistre' => 'Ši interneto svetainė jau yra užregistruota',
	'form_pet_url_invalide' => 'Jūsų nurodytas URL adresas negaliojantis',
	'form_pet_votre_email' => 'Jūsų el. pašto adresas',
	'form_pet_votre_nom' => 'Jūsų vardas arba pseudonimas', # MODIF

	// I
	'info_adresse_email' => 'el. paštas:',
	'info_texte_message' => 'Jūsų žinutės tekstas:'
);

?>
